@@ -1,5 +1,5 @@
 package Plack::Handler::Stomp::Types;
-$Plack::Handler::Stomp::Types::VERSION = '1.14';
+$Plack::Handler::Stomp::Types::VERSION = '1.15';
 {
   $Plack::Handler::Stomp::Types::DIST = 'Plack-Handler-Stomp';
 }
@@ -17,7 +17,7 @@ use namespace::autoclean;
 # ABSTRACT: type definitions for Plack::Handler::Stomp
 
 
-duck_type Logger, [qw(debug info
+duck_type Logger, [qw(trace debug info
                       warn error)];
 
 
@@ -44,13 +44,13 @@ Plack::Handler::Stomp::Types - type definitions for Plack::Handler::Stomp
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 TYPES
 
 =head2 C<Logger>
 
-Any object that can C<debug>, C<info>, C<warn>, C<error>.
+Any object that can C<trace>, C<debug>, C<info>, C<warn>, C<error>.
 
 =head2 C<PathMapKey>
 
@@ -70,7 +70,7 @@ Gianni Ceccarelli <gianni.ceccarelli@net-a-porter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Net-a-porter.com.
+This software is copyright (c) 2020 by Net-a-porter.com.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
